pub fn system_cache_root_dir(codex_home: &AbsolutePathBuf) -> AbsolutePathBufExpand description
Returns the on-disk cache location for embedded system skills from an absolute CODEX_HOME.
pub fn system_cache_root_dir(codex_home: &AbsolutePathBuf) -> AbsolutePathBufReturns the on-disk cache location for embedded system skills from an absolute CODEX_HOME.